==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicInternalFrameTitlePane__24SystemMenuBar.h <==
// public class javax.swing.plaf.basic.BasicInternalFrameTitlePane$SystemMenuBar

// class file dependencies
// @dep_class d547e55bb64f2ca8 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6c83b58ef8abc63e javax_swing_JComponent
// @dep_class 620ef2039cfc877b javax_swing_JMenuBar
// @dep_class 9ff0a42abc4f0077 javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar

// header file dependencies
// @dep_header javax_swing_JMenuBar

#include "javax/swing/JMenuBar.h"

#ifndef _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar_H_
#define _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar_H_

// Forward structure declarations
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$sub_refs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$refs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$object	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$vmethods	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$vtable	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$vtype	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$method$_init$a4e5e3befc8ae789(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$object *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object *);

// Virtual methods
extern jboolean _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$method$isFocusTransversable$767c0b8a711921a3(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$object *);
extern jboolean _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$method$isOpaque$e0a7103e33c0b425(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$object *);
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$method$paint$76f038a09cf0c480(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$object *, struct _jc_java_awt_Graphics$object *);
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$method$requestFocus$52dfe65b451f120d(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$method_info$isFocusTransversable$767c0b8a711921a3;
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$method_info$isOpaque$e0a7103e33c0b425;
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$method_info$paint$76f038a09cf0c480;
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$method_info$requestFocus$52dfe65b451f120d;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$vmethods {
	jboolean	(*isFocusTransversable$767c0b8a711921a3)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$object *);
	jboolean	(*isOpaque$e0a7103e33c0b425)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$object *);
	void	(*paint$76f038a09cf0c480)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$object *, struct _jc_java_awt_Graphics$object *);
	void	(*requestFocus$52dfe65b451f120d)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_JMenuBar$vmethods	javax_swing_JMenuBar;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$vmethods	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$refs {
    _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$sub_refs	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar;
    _jc_javax_swing_JMenuBar$sub_refs	javax_swing_JMenuBar;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_JMenuBar$sub_nonrefs	javax_swing_JMenuBar;
    _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$sub_nonrefs	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$object {
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$vtype _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicInternalFrameTitlePane__24SystemMenuBar.h <==
// public class javax.swing.plaf.basic.BasicInternalFrameTitlePane$SystemMenuBar

// class file dependencies
// @dep_class 5a2bf6e9db456f42 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c84352ee73c7cec1 javax_swing_JComponent
// @dep_class 620ef2039cfc877b javax_swing_JMenuBar
// @dep_class 9ff0a42abc4f0077 javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar

// header file dependencies
// @dep_header javax_swing_JMenuBar

#include "javax/swing/JMenuBar.h"

#ifndef _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar_H_
#define _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar_H_

// Forward structure declarations
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$sub_refs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$refs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$nonrefs	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$object	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$vmethods	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$vtable	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$vtype	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$method$_init$a4e5e3befc8ae789(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$object *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$method$isFocusTransversable$767c0b8a711921a3(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$method$isOpaque$e0a7103e33c0b425(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$method$paint$76f038a09cf0c480(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$object *, struct _jc_java_awt_Graphics$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$method$requestFocus$52dfe65b451f120d(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$method_info$isFocusTransversable$767c0b8a711921a3;
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$method_info$isOpaque$e0a7103e33c0b425;
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$method_info$paint$76f038a09cf0c480;
extern _jc_method _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$method_info$requestFocus$52dfe65b451f120d;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$vmethods {
	jboolean	(*isFocusTransversable$767c0b8a711921a3)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$object *) _JC_JCNI_ATTR;
	jboolean	(*isOpaque$e0a7103e33c0b425)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$object *) _JC_JCNI_ATTR;
	void	(*paint$76f038a09cf0c480)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$object *, struct _jc_java_awt_Graphics$object *) _JC_JCNI_ATTR;
	void	(*requestFocus$52dfe65b451f120d)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_JMenuBar$vmethods	javax_swing_JMenuBar;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$vmethods	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$refs {
    _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$sub_refs	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar;
    _jc_javax_swing_JMenuBar$sub_refs	javax_swing_JMenuBar;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_JMenuBar$sub_nonrefs	javax_swing_JMenuBar;
    _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$sub_nonrefs	javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$object {
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$vtype _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicInternalFrameTitlePane__24SystemMenuBar_H_ */
